@@ -35,37 +35,17 @@ package Algorithm::Evolutionary::Utils;
 use Exporter;
 our @ISA = qw(Exporter);
 
-use version; our $VERSION =  qv("3.403");
+use version; our $VERSION =  qv("4.00.00");
 
-our @EXPORT_OK = qw( entropy genotypic_entropy consensus hamming 
-		     random_bitstring random_number_array average 
-		     parse_xml decode_string vector_compare);
+our @EXPORT_OK = qw( genotypic_entropy consensus hamming 
+		     random_bitstring random_number_array 
+		     decode_string vector_compare);
 
 use Carp;
 use String::Random;
 use XML::Parser;
 use Statistics::Basic qw(mean);
 
-=head2 entropy( $population)
-
-Computes the entropy using the well known Shannon's formula: L<http://en.wikipedia.org/wiki/Information_entropy>
-'to avoid botching highlighting
-
-=cut
-
-sub entropy {
-  my $population = shift;
-  my %frequencies;
-  map( (defined $_->{'_fitness'})?$frequencies{$_->{'_fitness'}}++:1, @$population );
-  my $entropy = 0;
-  my $gente = scalar(@$population); # Population size
-  for my $f ( keys %frequencies ) {
-    my $this_freq = $frequencies{$f}/$gente;
-    $entropy -= $this_freq*log( $this_freq );
-  }
-  return $entropy;
-}
-
 =head2 genotypic_entropy( $population)
 
 Computes the entropy using the well known Shannon's formula:
@@ -112,13 +92,14 @@ sub consensus {
   my $rough = shift;
   my @frequencies;
   for ( @$population ) {
-      for ( my $i = 0; $i < length($_->{'_str'}); $i ++ ) {
-	  if ( !$frequencies[$i] ) {
-	      $frequencies[$i]={ 0 => 0,
-				 1 => 0};
-	  }
-	  $frequencies[$i]->{substr($_->{'_str'}, $i, 1)}++;
+    my $str = ref( $_ )?$_->{'_str'}:$_;
+    for ( my $i = 0; $i < length($str); $i ++ ) {
+      if ( !$frequencies[$i] ) {
+	$frequencies[$i]={ 0 => 0,
+			   1 => 0};
       }
+      $frequencies[$i]->{ substr($str, $i, 1)}++;
+    }
   }
   my $consensus;
   for my $f ( @frequencies ) {
@@ -145,20 +126,6 @@ sub consensus {
   return $consensus;
 }
 
-=head2 average( $population )
-
-Computes an average of population fitness
-
-=cut
-
-sub average {
-  my $population = shift;
-  my @frequencies;
-  my @fitnesses = map( $_->{'_fitness'}, @$population );
-  return mean( @fitnesses );
-
-}
-
 =head2 random_bitstring( $bits[, $chromify = 0 ] )
 
 Returns a random bitstring with the stated number of bits. Useful for
@@ -222,7 +189,7 @@ Compares vectors, returns 1 if 1 dominates 2, -1 if it's the other way
 round, and 0 if neither dominates the other. Both vectors are supposed
 to be numeric. Returns C<0> if neither is bigger, and they are not
 equal. Fails if the length is not the same. None of the combinations
-above, returns C<undef>.
+above returns C<undef>.
 
 =cut
 
